@@ -25,6 +25,19 @@ format_str = """
 --------------------------------------
 """
 
+def fromisoformat(date_string: str):
+    dt = datetime.datetime.fromisoformat(date_string).replace(microsecond=0)
+    if not dt.tzinfo:
+        now = datetime.datetime.now().astimezone()
+        dt = dt.replace(tzinfo=now.tzinfo)
+    return dt
+
+import datetime
+
+now = datetime.datetime.now().astimezone()
+then = datetime.datetime.fromisoformat("2022-10-07T22:15:00")
+than = then.replace(tzinfo=now.tzinfo)
+
 def parse_args(ctl_args):
     parser = argparse.ArgumentParser()
     parser.add_argument("device_mac", nargs='?', help="Aranet4 Bluetooth Address")
@@ -43,14 +56,14 @@ def parse_args(ctl_args):
         "-s",
         "--start",
         metavar="DATE",
-        type=datetime.datetime.fromisoformat,
+        type=fromisoformat,
         help="Records range start (UTC time, example: 2019-09-29T14:00:00",
     )
     history.add_argument(
         "-e",
         "--end",
         metavar="DATE",
-        type=datetime.datetime.fromisoformat,
+        type=fromisoformat,
         help="Records range end (UTC time, example: 2019-09-30T14:00:00",
     )
     history.add_argument(
